@@ -54,20 +54,25 @@ use strict;
 use Carp;
 use IO::File;
 use Pod::PlainText;
+use Regexp::Common qw( URI );
 
 use vars qw( @ISA $VERSION );
 
 @ISA = qw( Pod::PlainText );
 
-$VERSION = '0.08';
+$VERSION = '0.10';
 
 =begin internal
 
+=over 12
+
 =item initialize
 
 Override adds the C<readme_type> and <debug> options, and initializes
 the "README_SKIP" flag.
 
+=back
+
 =end internal
 
 =cut
@@ -93,13 +98,16 @@ the "README_SKIP" flag.
   }
 }
 
-
 =begin internal
 
+=over 12 
+
 =item output
 
 Override does not output anything if the "README_SKIP" flag is enabled.
 
+=back
+
 =end internal
 
 =cut
@@ -113,10 +121,14 @@ sub output {
 
 =begin internal
 
+=over
+
 =item _parse_args
 
 Parses destination and name="value" arguments passed for L</cmd_for>.
 
+=back
+
 =end internal
 
 =cut
@@ -163,10 +175,14 @@ sub _parse_args {
 
 =begin internal
 
+=over
+
 =item cmd_begin
 
 Overrides support for "begin" command.
 
+=back
+
 =end internal
 
 =cut
@@ -198,10 +214,14 @@ sub cmd_begin {
 
 =begin internal
 
+=over
+
 =item cmd_for
 
 Overrides support for "for" command.
 
+=back
+
 =end internal
 
 =cut
@@ -247,10 +267,14 @@ sub cmd_for {
 
 =begin internal
 
+=over
+
 =item _include_file
 
 Includes a file.
 
+=back
+
 =end internal
 
 =cut
@@ -286,10 +310,14 @@ sub _include_file {
 
 =begin internal
 
+=over
+
 =item seq_l
 
 Overrides support for "L" markup.
 
+=back
+
 =end internal
 
 =cut
@@ -313,8 +341,10 @@ sub seq_l {
     # name.  Note that L<manpage/> forces a manpage interpretation, as does
     # something looking like L<manpage(section)>.  The latter is an
     # enhancement over the original Pod::Text.
+
+
     my ($manpage, $section) = ('', $_);
-    if (/^(?:https?|ftp|news):/) {
+    if (/$RE{URI}/ || /^(?:https?|ftps?|svn):/) {
         # a URL
         return $_;
     } elsif (/^"\s*(.*?)\s*"$/) {
@@ -332,7 +362,6 @@ sub seq_l {
     }
 }
 
-
 =head1 DESCRIPTION
 
 This module is a subclass of L<Pod::PlainText> which provides additional
@@ -375,7 +404,7 @@ Special POD markup options are described below:
 =item begin/end
 
   =begin readme
-  
+
   =head1 README ONLY
 
   This section will only show up in the README file.
@@ -409,7 +438,7 @@ a C<continue> command occurs:
 
   =for readme include file=filename type=type start=Regexp stop=Regexp
 
-  =for readme include file=Changes start=^0.08 stop=^0.06 type=text
+  =for readme include file=Changes start=^0.09 stop=^0.081 type=text
 
 Includes a plaintext file named F<filename>, starting with the line
 that contains the start C<Regexp> and ending at the line that begins
@@ -457,32 +486,23 @@ Warnings will be issued for any ignored formatting commands.
 
 For an example, see the F<Readme.pm> file in this distribution.
 
-=for readme continue
-
-=begin readme
-
-=head1 REVSION HISTORY
-
-Changes since the last release:
-
-=for readme include file="Changes" start="^0.08" stop="^0.05" type="text"
-
-A detailed history is available in the F<Changes> file.
-
-=end readme
-
 =head1 SEE ALSO
 
 See L<perlpod>, L<perlpodspec> and L<podlators>.
 
 =head1 AUTHOR
 
-Robert Rothenberg <rrwo at cpan.org>
+Originally by Robert Rothenberg <rrwo at cpan.org>
 
-=head2 Suggestions and Bug Reporting
+Now maintained by David Precious <davidp@preshweb.co.uk>
+
+
+=head2 Suggestions, Bug Reporting and Contributing
+
+This module is developed on GitHub at:
+
+http://github.com/bigpresh/Pod-Readme
 
-Feedback is always welcome.  Please use the CPAN Request Tracker at
-L<http://rt.cpan.org> to submit bug reports.
 
 =head1 LICENSE
 
